Module: Decidim::Toggle::ExposeAttributesToJs

Extended by:
ActiveSupport::Concern
Defined in:
lib/decidim/toggle/expose_attributes_to_js.rb

Overview

Opt-in DSL to expose module config form attributes to window.DecidimToggle. To add this in your form, you need to add the following:

include Decidim::Toggle::ExposeAttributesToJs
expose_to_javascript :enabled, :search_bar