Class: Decidim::Toggle::UpdateEmailsForm
- Inherits:
-
System::BaseOrganizationForm
- Object
- System::BaseOrganizationForm
- Decidim::Toggle::UpdateEmailsForm
- Defined in:
- app/forms/decidim/toggle/update_emails_form.rb
Instance Method Summary collapse
-
#host ⇒ Object
These tabs only update a small JSONB slice (SMTP settings).
- #users_registration_mode ⇒ Object
Instance Method Details
#host ⇒ Object
These tabs only update a small JSONB slice (SMTP settings).
The generic system form validates presence of host and
users_registration_mode, so fall back to the current organization when
those attributes aren't part of the tab payload.
12 13 14 |
# File 'app/forms/decidim/toggle/update_emails_form.rb', line 12 def host super.presence || current_organization&.host end |
#users_registration_mode ⇒ Object
16 17 18 |
# File 'app/forms/decidim/toggle/update_emails_form.rb', line 16 def users_registration_mode super.presence || current_organization&.users_registration_mode end |